TestCase subclass: #YAXParserTests
	instanceVariableNames: 'testsToSkip '
	classVariableNames: ''
	poolDictionaries: ''
	category: 'XML-Testing'!

!YAXParserTests methodsFor: 'private' stamp: 'mir 12/11/2000 13:36'!
assert: aBoolean
	aBoolean
		ifFalse: [self halt]! !

!YAXParserTests methodsFor: 'private' stamp: 'mir 12/11/2000 13:53'!
parseValidFile: stream 
	| result |
	result _ XMLCanonical parseDocumentFrom: stream.
	stream close.
	^result! !

!YAXParserTests methodsFor: 'private' stamp: 'mir 12/11/2000 13:30'!
runTest: fileName 
	| stream result |
	stream _ (FileDirectory forFileName: fileName) readOnlyFileNamed: fileName.
	result _ XMLCanonical parseDocumentFrom: stream.
	stream close.
	^result! !

!YAXParserTests methodsFor: 'private' stamp: 'mir 12/11/2000 16:14'!
runTestClark: testNr standalone: saCat validity: validityCat
	"Verifies that internal parameter entities are correctly expanded within the internal subset.
	See XML Spec. 1.0 section: 4.4.8"
	|  correctAnswer  result testDir testFileName testId |

	(self shouldSkipTest: testNr standalone: saCat validity: validityCat)
		ifTrue:[^nil].
	testDir _ self testDirectoryForClarkStandalone: saCat validity: validityCat.
	testId _ testNr printString.
	testFileName _ '000.xml' copyReplaceFrom: 4 - testId size to: 3 with: testId.
	(testDir fileExists: testFileName)
		ifFalse: [^Transcript show: 'Skipped: ' , testId; cr].
	result := self parseValidFile: (testDir readOnlyFileNamed: testFileName).

	correctAnswer := ((testDir directoryNamed: 'out') readOnlyFileNamed: testFileName) contentsOfEntireFile.
	correctAnswer = result
		"ifTrue: [Transcript show: 'Passed: ' , testId; cr]"
		ifFalse: [Transcript show: 'Failed: ' , testId; cr]! !

!YAXParserTests methodsFor: 'private' stamp: 'mir 12/11/2000 13:31'!
shouldSkipTest: testId standalone: saCat validity: validityCat
	^false! !

!YAXParserTests methodsFor: 'private' stamp: 'mir 12/11/2000 13:33'!
testDirectoryForClarkStandalone: saCat validity: validityCat
	| testDir |
	testDir _ FileDirectory default directoryNamed: 'xmltest'.
	testDir _ testDir directoryNamed: validityCat.
	testDir _ testDir directoryNamed: saCat.
	^testDir! !


!YAXParserTests methodsFor: 'initialize'!
initialize
	testsToSkip := self class allTestsToSkip.! !

"-- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- "!

YAXParserTests class
	instanceVariableNames: ''!

!YAXParserTests class methodsFor: 'tests to skip'!
allTestsToSkip
	^(OrderedCollection new: 50)
		addAll: self clarkTestsToSkip;
		addAll: self sunTestsToSkip;
		addAll: self oasisTestsToSkip;
		yourself.! !

!YAXParserTests class methodsFor: 'tests to skip'!
clarkTestsToSkip
	
	^#( "invalid test"
		'valid-sa-012'	
		'valid-sa-105' " the answer the test gives seems incorrect, and parser seems correct"	

		"encoding problems"
"		'valid-sa-049' 'valid-sa-050' 'valid-sa-051' 'valid-sa-061' 'valid-sa-062'
		'valid-sa-063'  'valid-ext-sa-014'"
		"no space between attributes"
		'not-wf-sa-186'

		"Too many cr in parsers answer"
		'valid-sa-093'

		"illegal PE in DTD"
		'valid-sa-094'

		"cr problem should return an entity"
		'valid-sa-107'  'valid-sa-106' 
		)! !



!YAXParserTests class methodsFor: 'tests clark' stamp: 'mir 12/11/2000 13:40'!
runValidClarkTests
	| saTests notsaTests extsaTests tester |
	"YAXParserTests runValidClarkTests"

	saTests _ 1 to: 119.
	notsaTests _ 1 to: 31.
	extsaTests _ 1 to: 14.

	tester _ self new.
	saTests do: [:testId |
		tester runTestClark: testId standalone: 'sa' validity: 'valid']! !
